==> qtjambi-serialbus-debuginfo-macos-5.15.20.jar: sources/QtJambiSerialBus/metainfo.cpp <==
#include <QtJambi/MetaInfo>

void initialize_meta_info_QCanBus();
void initialize_meta_info_QCanBusDevice();
void initialize_meta_info_QCanBusDevice_Filter();
void initialize_meta_info_QCanBusDeviceInfo();
void initialize_meta_info_QCanBusFactory();
void initialize_meta_info_QCanBusFactoryV2();
void initialize_meta_info_QCanBusFrame();
void initialize_meta_info_QCanBusFrame_TimeStamp();
void initialize_meta_info_QModbusClient();
void initialize_meta_info_QModbusDataUnit();
void initialize_meta_info_QModbusDevice();
void initialize_meta_info_QModbusDeviceIdentification();
void initialize_meta_info_QModbusExceptionResponse();
void initialize_meta_info_QModbusPdu();
void initialize_meta_info_QModbusReply();
void initialize_meta_info_QModbusRequest();
void initialize_meta_info_QModbusRequest_CalcFunction();
void initialize_meta_info_QModbusResponse();
void initialize_meta_info_QModbusResponse_CalcFunction();
void initialize_meta_info_QModbusRtuSerialMaster();
void initialize_meta_info_QModbusRtuSerialSlave();
void initialize_meta_info_QModbusServer();
void initialize_meta_info_QModbusTcpClient();
void initialize_meta_info_QModbusTcpConnectionObserver();
void initialize_meta_info_QModbusTcpServer();

extern "C" Q_DECL_EXPORT jint JNICALL JNI_ONLOAD(JavaVM *, void *)
{
    QTJAMBI_LIBRARY_INITIALIZATION_METHOD_CALL("io.qt.serialbus")
    initialize_meta_info_QCanBus();
    initialize_meta_info_QCanBusDevice();
    initialize_meta_info_QCanBusDevice_Filter();
    initialize_meta_info_QCanBusDeviceInfo();
    initialize_meta_info_QCanBusFactory();
    initialize_meta_info_QCanBusFactoryV2();
    initialize_meta_info_QCanBusFrame();
    initialize_meta_info_QCanBusFrame_TimeStamp();
    initialize_meta_info_QModbusClient();
    initialize_meta_info_QModbusDataUnit();
    initialize_meta_info_QModbusDevice();
    initialize_meta_info_QModbusDeviceIdentification();
    initialize_meta_info_QModbusExceptionResponse();
    initialize_meta_info_QModbusPdu();
    initialize_meta_info_QModbusReply();
    initialize_meta_info_QModbusRequest();
    initialize_meta_info_QModbusRequest_CalcFunction();
    initialize_meta_info_QModbusResponse();
    initialize_meta_info_QModbusResponse_CalcFunction();
    initialize_meta_info_QModbusRtuSerialMaster();
    initialize_meta_info_QModbusRtuSerialSlave();
    initialize_meta_info_QModbusServer();
    initialize_meta_info_QModbusTcpClient();
    initialize_meta_info_QModbusTcpConnectionObserver();
    initialize_meta_info_QModbusTcpServer();
    return QTJAMBI_ONLOAD_RETURN;
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QtJambi_1LibraryUtilities_internalAccess)(JNIEnv *env, jclass cls){
    jobject result{0};
    QTJAMBI_TRY{
        result = MetaInfoAPI::internalAccess(env, cls);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(env);
    }QTJAMBI_TRY_END
    return result;
}

==> qtjambi-serialbus-debuginfo-macos-6.6.3.jar: sources/QtJambiSerialBus/metainfo.cpp <==
#include <QtJambi/MetaInfo>

void initialize_meta_info_QCanBus();
void initialize_meta_info_QCanBusDevice();
void initialize_meta_info_QCanBusDevice_Filter();
void initialize_meta_info_QCanBusDeviceInfo();
void initialize_meta_info_QCanBusFactory();
void initialize_meta_info_QCanBusFrame();
void initialize_meta_info_QCanBusFrame_TimeStamp();
void initialize_meta_info_QCanDbcFileParser();
void initialize_meta_info_QCanFrameProcessor();
void initialize_meta_info_QCanFrameProcessor_ParseResult();
void initialize_meta_info_QCanMessageDescription();
void initialize_meta_info_QCanSignalDescription();
void initialize_meta_info_QCanSignalDescription_MultiplexValueRange();
void initialize_meta_info_QCanUniqueIdDescription();
void initialize_meta_info_QModbusClient();
void initialize_meta_info_QModbusDataUnit();
void initialize_meta_info_QModbusDevice();
void initialize_meta_info_QModbusDeviceIdentification();
void initialize_meta_info_QModbusExceptionResponse();
void initialize_meta_info_QModbusPdu();
void initialize_meta_info_QModbusReply();
void initialize_meta_info_QModbusRequest();
void initialize_meta_info_QModbusRequest_CalcFunction();
void initialize_meta_info_QModbusResponse();
void initialize_meta_info_QModbusResponse_CalcFunction();
void initialize_meta_info_QModbusRtuSerialClient();
void initialize_meta_info_QModbusRtuSerialServer();
void initialize_meta_info_QModbusServer();
void initialize_meta_info_QModbusTcpClient();
void initialize_meta_info_QModbusTcpConnectionObserver();
void initialize_meta_info_QModbusTcpServer();
void initialize_meta_info_QtCanBus();

extern "C" Q_DECL_EXPORT jint JNICALL JNI_ONLOAD(JavaVM *, void *)
{
    QTJAMBI_LIBRARY_INITIALIZATION_METHOD_CALL("io.qt.serialbus")
    initialize_meta_info_QCanBus();
    initialize_meta_info_QCanBusDevice();
    initialize_meta_info_QCanBusDevice_Filter();
    initialize_meta_info_QCanBusDeviceInfo();
    initialize_meta_info_QCanBusFactory();
    initialize_meta_info_QCanBusFrame();
    initialize_meta_info_QCanBusFrame_TimeStamp();
    initialize_meta_info_QCanDbcFileParser();
    initialize_meta_info_QCanFrameProcessor();
    initialize_meta_info_QCanFrameProcessor_ParseResult();
    initialize_meta_info_QCanMessageDescription();
    initialize_meta_info_QCanSignalDescription();
    initialize_meta_info_QCanSignalDescription_MultiplexValueRange();
    initialize_meta_info_QCanUniqueIdDescription();
    initialize_meta_info_QModbusClient();
    initialize_meta_info_QModbusDataUnit();
    initialize_meta_info_QModbusDevice();
    initialize_meta_info_QModbusDeviceIdentification();
    initialize_meta_info_QModbusExceptionResponse();
    initialize_meta_info_QModbusPdu();
    initialize_meta_info_QModbusReply();
    initialize_meta_info_QModbusRequest();
    initialize_meta_info_QModbusRequest_CalcFunction();
    initialize_meta_info_QModbusResponse();
    initialize_meta_info_QModbusResponse_CalcFunction();
    initialize_meta_info_QModbusRtuSerialClient();
    initialize_meta_info_QModbusRtuSerialServer();
    initialize_meta_info_QModbusServer();
    initialize_meta_info_QModbusTcpClient();
    initialize_meta_info_QModbusTcpConnectionObserver();
    initialize_meta_info_QModbusTcpServer();
    initialize_meta_info_QtCanBus();
    return QTJAMBI_ONLOAD_RETURN;
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QtJambi_1LibraryUtilities_internalAccess)(JNIEnv *env, jclass cls){
    jobject result{0};
    QTJAMBI_TRY{
        result = MetaInfoAPI::internalAccess(env, cls);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(env);
    }QTJAMBI_TRY_END
    return result;
}
